@@ -1,4 +1,4 @@
-__version__ = '0.2.2'
+__version__ = '0.3.0'
 
 from .core import (
     predict_all_visible_satellite_overpasses,
@@ -35,15 +35,13 @@ from .observers import (
     PredictedPass,
 )
 
-# from .constants import (
-#     R_EARTH,
-# )
 
 __all__ = [
     'predict_all_visible_satellite_overpasses',
     'predict_single_satellite_overpasses',
     'predict_next_overpass',
     'get_next_pass_detail',
+    'get_satellite_llh',
     'Location',
     'AsyncPasspredictTLESource',
     'PasspredictTLESource',
