@@ -3,4 +3,8 @@ class NotReachable(Exception):
 
 
 class PropagationError(Exception):
-    """Raised when a calculation issue is found"""
\ No newline at end of file
+    """Raised when a calculation issue is found"""
+
+
+class CelestrakError(Exception):
+    """ Raised when TLEs can't be downloaded from Celestrak """
\ No newline at end of file
